#
# spec file for package yast2-migration
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-migration
Version:        4.2.5
Release:        3.3.1
Summary:        YaST2 - Online migration
License:        GPL-2.0-only
Group:          System/YaST
URL:            https://github.com/yast/yast-migration

Source0:        %{name}-%{version}.tar.bz2

BuildRequires:  yast2 >= 3.1.130
BuildRequires:  yast2-buildtools >= 4.2.2
BuildRequires:  yast2-packager
BuildRequires:  yast2-ruby-bindings
BuildRequires:  rubygem(%{rb_default_ruby_abi}:rspec)
BuildRequires:  rubygem(%{rb_default_ruby_abi}:yast-rake)
# needed in build for testing
BuildRequires:  update-desktop-files
BuildRequires:  yast2-installation >= 3.1.137
BuildRequires:  yast2-update

Requires:       yast2 >= 3.1.130
# product_update_summary, product_update_warning
Requires:       yast2-packager >= 4.2.33
Requires:       yast2-pkg-bindings
Requires:       yast2-ruby-bindings
# new rollback client
Requires:       yast2-registration >= 3.1.153
# need recent enough installation for working proposal runner
Requires:       yast2-installation >= 3.1.146
Requires:       yast2-update

# Older snapper does not provide machine-readable output
Conflicts:      snapper < 0.8.6

Supplements:    yast2-registration

BuildArch:      noarch

%description
This package contains the YaST2 component for online migration.

%prep
%setup -q

%check
%yast_check

%build

%install
%yast_install
%yast_metainfo

%files
%{yast_clientdir}
%{yast_libdir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_icondir}
%license COPYING
%doc %{yast_docdir}

%changelog
* Wed May 12 2021 lslezak@suse.cz
- Show the new base product license in online migration
  (bsc#1185808)
- 4.2.5
* Tue Nov 19 2019 schubi@suse.de
- Using Y2Packager::Resolvable.any? and Y2Packager::Resolvable.find
  in order to decrease the required memory (bsc#1132650,
  bsc#1140037).
- 4.2.4
* Mon Oct 28 2019 jlopez@suse.com
- Use new snapper machine-readable output to check whether snapper
  is configured (related to bsc#1149322).
- 4.2.3
* Thu Aug 22 2019 schubi@suse.de
- Using rb_default_ruby_abi tag in the spec file in order to
  handle several ruby versions (bsc#1146403).
- 4.2.2
* Fri Jul 19 2019 lslezak@suse.cz
- Added "BuildRequires: update-desktop-files"
- Related to the previous desktop file changes (fate#319035)
- 4.2.1
* Fri May 31 2019 hellcp@mailbox.org
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.0
* Thu May 30 2019 lslezak@suse.cz
- Fixes for the openSUSE Leap => SLES migration (jsc#SLE-7006)
  - Enable the openSUSE => SUSE vendor change
  - Disable all other repositories (esp. the default OSS and
    non-OSS repositories) which could collide with the new SLES
    repositories
- 4.1.2
* Thu Nov 29 2018 lslezak@suse.cz
- Build fix, update unit tests related to the icon handling
  (boo#1109310)
- 4.1.1
* Sun Nov 25 2018 hellcp@mailbox.org
- Provide icon with module (boo#1109310)
- 4.1.0
* Wed Oct 17 2018 schubi@suse.de
- Added %%license to spec file. Needed to build
  fix for bsc#1071757 again.
- 4.0.1
* Thu Dec  7 2017 igonzalezsosa@suse.com
- Bump version to follow the new versioning guidelines
  (related to bsc#1071757).
- 4.0.0
* Tue Jun  6 2017 mfilka@suse.com
- bnc#1040118
  - moved YCC laucher from "System" into "Software" group even in
    GTK
- 3.2.0
* Thu Nov 26 2015 stephan.barth@suse.com
- Added Supplements for yast2-registration to ensure automatic installation
  (bsc#982150)
- 3.1.13.1
* Thu Oct  8 2015 lslezak@suse.cz
- fixed crash in the migration proposal (do not use "return"
  for returning the client result value) (bsc#949484)
- 3.1.13
* Tue Oct  6 2015 lslezak@suse.cz
- display a hint to manually rollback the system when migration
  fails or is aborted during package installation (FATE#315161)
- 3.1.12
* Thu Sep 24 2015 lslezak@suse.cz
- do not display the "success" dialog when the package installation
  is aborted (bsc#947416)
- 3.1.11
* Tue Sep 22 2015 lslezak@suse.cz
- rollback registration when migration is aborted after registering
  the migration products (FATE#315161)
- 3.1.10
* Wed Sep 16 2015 lslezak@suse.cz
- install package management patches at the beginning to ensure
  the latest migration packages are used (bsc#945032)
- 3.1.9
* Mon Sep 14 2015 lslezak@suse.cz
- add "important" flag to the snapshots created by the migration
  module (bsc#944019)
- disable the default snapshots created by the zypp plugin
  (bsc#944019)
- 3.1.9
* Tue Sep  1 2015 lslezak@suse.cz
- disable "Back" at the initial dialog
- restore (enable) the Updates repositories at the end of the
  migration workflow (bsc#943960)
- 3.1.8
* Wed Aug 19 2015 lslezak@suse.cz
- create the "post" snapshot after restart to avoid possible issues
  with fast_gettext (bnc#942080)
- 3.1.7
* Tue Aug 18 2015 lslezak@suse.cz
- create a pair of "pre" and "post" filesystem snapshots (instead
  of a single snapshot) (bsc#942110)
- 3.1.6
* Tue Aug 18 2015 lslezak@suse.cz
- restart YaST after upgrading the packages to avoid using the old
  (removed) files (bnc#942080)
- 3.1.5
* Fri Aug 14 2015 lslezak@suse.cz
- ignore the installed products when searching for obsolete
  repositories (bsc#941532)
- 3.1.4
* Thu Aug 13 2015 lslezak@suse.cz
- display a finish dialog at the very end, suggest rebooting the
  machine to activate the changes (new kernel, ...) (bsc#941625)
- 3.1.3
* Wed Aug  5 2015 lslezak@suse.cz
- display a warning for repositories providing an obsolete product
  (FATE#319130)
- 3.1.2
* Thu Jul  2 2015 lslezak@suse.cz
- call the registration client to add and configure the migration
  repositories (FATE#315161)
- use a specific migration proposal client
- 3.1.1
* Wed Mar 25 2015 jreidinger@suse.com
- initial package
